# HoneyPy Copyright (C) 2013-2016 foospidy
# https://github.com/foospidy/HoneyPy
# See LICENSE for details
# HoneyPy elasticsearch logger

import sys
import hashlib
import urllib
import requests
import base64
import Geohash
from geoip import geolite2
from datetime import datetime
from twisted.python import log

# prevent creation of compiled bytecode files
sys.dont_write_bytecode = True

def post_elasticsearch(useragent, url, date, time, date_time, millisecond, session, protocol, event, local_host, local_port, service, remote_host, remote_port, data):
	# post events to honeydb logger
	h = hashlib.md5()
	h.update(data)
        login = base64.b64encode(bytes('honeypy:xxxxxxxxxxx'))
	#formatting date_time as iso format so that Kibana will recognize it as a date field
	date_time = datetime.strptime(date_time,"%Y-%m-%d %H:%M:%S").isoformat()
	geoip = geolite2.lookup(remote_host)
	headers = { 'User-Agent': useragent, "Content-Type": "application/json", 'Authorization': 'Basic %s' % login }
        if geoip is not None:
           if geoip.country:
               country=geoip.country
           else:
               country="unknown"
           if geoip.continent:
              continent=geoip.continent
           else:
              continent="unknown"
           if geoip.location:
              geohash=Geohash.encode(geoip.location[0],geoip.location[1])
        else:
	   country="unknown"
           continent="unknown"
           geohash=""

	# applying [:-3] to time to truncate millisecond
	data    = {
		'date': date,
		'time': time,
		'date_time': date_time,
		'millisecond': str(millisecond)[:-3],
		'session': session,
		'protocol': protocol,
		'event': event,
		'local_host': local_host,
		'local_port': local_port,
		'service': service,
		'remote_host': remote_host,
		'remote_port': remote_port,
		'data': data,
  		'plain_data': data.decode('hex'),
		'bytes': str(len(data)),
		'data_hash': h.hexdigest(),
                'geoiphash': geohash,
                'ipcontinent': continent,
                'ipcountry': country
	}
       
        
	try:
		r       = requests.post(url, headers=headers, json=data)
		page    = r.text
		
		log.msg('Post event to elasticsearch, response: %s' % (str(page).strip()))
                fileblock = open("/home/honeypot/HoneyPy/log/ipstoblock.log", "a")
                fileblock.write("TIME:"+str(time)+" IP:"+str(remote_host)+"\n") 
                fileblock.close()       
	except Exception as e:
		log.msg('Error posting to elasticsearch: %s' % (str(e.message).strip()))
